fnss.netconfig.nodeconfig.add_stack — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.add_stack

`add_stack`(topology, node, name, properties=None, **kwargs)

  Set stack on a node.

  If the node already has a stack, it is overwritten

  Parameters: | topology : Topology The topology node : any hashable type The ID of the node name : str The name of the stack properties : dict, optional The properties of the stack **attr : keyworded attributes Further properties of the application

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »